@@ -470,6 +470,8 @@ rm {self.SCRIPTS_PREFIX_NAME_FILE}*
                 if "SESSION_TOKEN" in env:
                     value = Style.IMAGENTA + "*".ljust(10,"*") + Style.GREEN + value[250:] 
                 prettyTable.addRow([idx,env,value])
+        if idx < 1:
+            prettyTable.addRow(["","",""])
         tableArgs = TableArgs()
         prettyTable.sortByColumn(int(tableArgs.sortCol) - 1)
         prettyTable.ascendingOrder(not tableArgs.desc)
